@@ -1,11 +1,12 @@
 'use strict'
-var helper = require('./test-helper')
-var pg = helper.pg
+const helper = require('./test-helper')
+const pg = helper.pg
 const suite = new helper.Suite()
 const pool = new pg.Pool()
+const assert = require('assert')
 
 suite.test('can access results when no rows are returned', function (done) {
-  var checkResult = function (result) {
+  const checkResult = function (result) {
     assert(result.fields, 'should have fields definition')
     assert.equal(result.fields.length, 1)
     assert.equal(result.fields[0].name, 'val')
@@ -15,7 +16,7 @@ suite.test('can access results when no rows are returned', function (done) {
   pool.connect(
     assert.success(function (client, release) {
       const q = new pg.Query('select $1::text as val limit 0', ['hi'])
-      var query = client.query(
+      const query = client.query(
         q,
         assert.success(function (result) {
           checkResult(result)
